@@ -18,7 +18,7 @@ rgmix <- function(N,window,v=4,S=NULL,extras=FALSE,...){
   if(!all(dim(S)==2)) stop("'S' must be a 2x2 matrix")
   if(!isSymmetric(S)||det(S)<=0) stop("'S' must be symmetric and positive-definite")
 
-  pts <- runifpoint(N,window)
+  pts <- spatstat.random::runifpoint(N,window)
   mn <- rbind(pts$x,pts$y)
   vcvarray <- array(0,dim=c(2,2,N))
   for(i in 1:N) vcvarray[,,i] <- riw(v,S)
